@@ -1,7 +1,6 @@
 import unittest
 from collections import UserDict
 from jacobsjsondoc.loader import PrepopulatedLoader
-from jacobsjsondoc.resolver import PassThroughResolver
 from jacobsjsondoc.document import create_document, RefResolutionMode, DocReference, DocValue, DocObject, CircularDependencyError
 
 SIMPLE_YAML = """
@@ -54,7 +53,7 @@ class TestDocument(unittest.TestCase):
     def test_lines(self):
         ppl = PrepopulatedLoader()
         ppl.prepopulate(None, SIMPLE_YAML)
-        doc = create_document(uri=None, resolver=None, loader=ppl)
+        doc = create_document(uri=None, loader=ppl)
         
         self.assertEqual(doc['jacob'].line, 2)
         self.assertEqual(doc['jacob']['brunson'].line, 3)
@@ -64,7 +63,7 @@ class TestDocument(unittest.TestCase):
     def test_local_ref_use_reference_objects(self):
         ppl = PrepopulatedLoader()
         ppl.prepopulate("yaml_with_ref", YAML_WITH_REF)
-        doc = create_document(uri="yaml_with_ref", resolver=None, loader=ppl, ref_resolution=RefResolutionMode.USE_REFERENCES_OBJECTS)
+        doc = create_document(uri="yaml_with_ref", loader=ppl, ref_resolution=RefResolutionMode.USE_REFERENCES_OBJECTS)
         self.assertIsInstance(doc['house']['local'], DocReference)
         node = doc['house']['local'].resolve()
         self.assertIsInstance(node, DocValue)
@@ -74,7 +73,7 @@ class TestDocument(unittest.TestCase):
         ppl = PrepopulatedLoader()
         ppl.prepopulate("local", YAML_WITH_REF)
         ppl.prepopulate("remote", SIMPLE_YAML)
-        doc = create_document(uri="local", resolver=PassThroughResolver(), loader=ppl, ref_resolution=RefResolutionMode.RESOLVE_REFERENCES)
+        doc = create_document(uri="local", loader=ppl, ref_resolution=RefResolutionMode.RESOLVE_REFERENCES)
         self.assertIsInstance(doc['house']['local'], DocValue)
         self.assertEqual(doc['house']['local'].value, "this is the value of the var")
 
@@ -82,7 +81,7 @@ class TestDocument(unittest.TestCase):
         ppl = PrepopulatedLoader()
         ppl.prepopulate("local", YAML_WITH_REF)
         ppl.prepopulate("remote", SIMPLE_YAML)
-        doc = create_document(uri="local", resolver=PassThroughResolver(), loader=ppl, ref_resolution=RefResolutionMode.USE_REFERENCES_OBJECTS)
+        doc = create_document(uri="local", loader=ppl, ref_resolution=RefResolutionMode.USE_REFERENCES_OBJECTS)
         self.assertIsInstance(doc['house']['remote'], DocReference)
         node = doc['house']['remote'].resolve()
         self.assertIsInstance(node, DocValue)
@@ -93,7 +92,7 @@ class TestDocument(unittest.TestCase):
         ppl = PrepopulatedLoader()
         ppl.prepopulate("local", YAML_WITH_REF)
         ppl.prepopulate("remote", SIMPLE_YAML)
-        doc = create_document(uri="local", resolver=PassThroughResolver(), loader=ppl, ref_resolution=RefResolutionMode.RESOLVE_REFERENCES)
+        doc = create_document(uri="local", loader=ppl, ref_resolution=RefResolutionMode.RESOLVE_REFERENCES)
         self.assertIsInstance(doc['house']['remote'], DocValue)
         self.assertEqual(doc['house']['remote'].value, "this is a foo string")
 
@@ -102,7 +101,7 @@ class TestDocument(unittest.TestCase):
         ppl.prepopulate("middle", YAML_WITH_REF)
         ppl.prepopulate("remote", SIMPLE_YAML)
         ppl.prepopulate("local", ANOTHER_YAML_WITH_REF)
-        doc = create_document(uri="local", resolver=PassThroughResolver(), loader=ppl, ref_resolution=RefResolutionMode.RESOLVE_REFERENCES)
+        doc = create_document(uri="local", loader=ppl, ref_resolution=RefResolutionMode.RESOLVE_REFERENCES)
         self.assertIsInstance(doc['colorado']['springs'], DocObject)
         self.assertIsInstance(doc['colorado']['springs']['var'], DocValue)
         self.assertEqual(doc['colorado']['springs']['var'].value, "this is the value of the var")
@@ -126,7 +125,7 @@ class TestDocument(unittest.TestCase):
         ppl.prepopulate("one", yaml1)
         ppl.prepopulate("two", yaml2)
         with self.assertRaises(CircularDependencyError):
-            doc = create_document(uri="one", resolver=PassThroughResolver(), loader=ppl, ref_resolution=RefResolutionMode.RESOLVE_REFERENCES)
+            doc = create_document(uri="one", loader=ppl, ref_resolution=RefResolutionMode.RESOLVE_REFERENCES)
 
 
 class TestDocumentTypes(unittest.TestCase):
@@ -134,7 +133,7 @@ class TestDocumentTypes(unittest.TestCase):
     def setUp(self):
         ppl = PrepopulatedLoader()
         ppl.prepopulate(None, YAML_TYPES)
-        self.doc = create_document(uri=None, resolver=None, loader=ppl)
+        self.doc = create_document(uri=None, loader=ppl)
 
     def test_userdict(self):
         self.assertIsInstance(self.doc['myobject'], dict)
@@ -169,7 +168,7 @@ class TestDocumentSimpleTypes(unittest.TestCase):
     def test_integer(self):
         ppl = PrepopulatedLoader()
         ppl.prepopulate(None, SIMPLE_WITH_INTEGER)
-        self.doc = create_document(uri=None, resolver=None, loader=ppl)
+        self.doc = create_document(uri=None, loader=ppl)
         self.assertEqual(self.doc['thevalue'], 42)
         self.assertIsInstance(self.doc['thevalue'], int)
         self.assertEqual(self.doc['thevalue'].line, 1)
@@ -188,7 +187,7 @@ class TestDocumentReference(unittest.TestCase):
         ppl = PrepopulatedLoader()
         ppl.prepopulate("local", doc_text)
         ppl.prepopulate("http://example.org/schema", remote)
-        self.doc = create_document(uri="local", resolver=None, loader=ppl)
+        self.doc = create_document(uri="local", loader=ppl)
 
     def test_loaded_reference(self):
         self.assertIsInstance(self.doc, dict)
