@@ -3,7 +3,6 @@ from .context import jacobsjsondoc
 from jacobsjsondoc.reference import JsonReference, ReferenceDictionary
 from jacobsjsondoc.document import create_document, RefResolutionMode, DocReference
 from jacobsjsondoc.loader import PrepopulatedLoader
-from jacobsjsondoc.resolver import PassThroughResolver
 import json
 
 SAMPLE_DOCUMENT = {
@@ -84,7 +83,7 @@ class TestIdTagging(unittest.TestCase):
         self.data = SAMPLE_DOCUMENT
         ppl = PrepopulatedLoader()
         ppl.prepopulate(self.data["$id"], json.dumps(self.data))
-        self.doc = create_document(uri=self.data["$id"], resolver=PassThroughResolver(), loader=ppl, ref_resolution=RefResolutionMode.USE_REFERENCES_OBJECTS)
+        self.doc = create_document(uri=self.data["$id"], loader=ppl, ref_resolution=RefResolutionMode.USE_REFERENCES_OBJECTS)
     
     def test_root_has_correct_id(self):
         self.assertEquals(self.doc._dollar_id.uri, self.data["$id"])
@@ -136,7 +135,7 @@ class TestDoubleRef(unittest.TestCase):
         self.data = DOUBLE_REFERENCE_DOC
         ppl = PrepopulatedLoader()
         ppl.prepopulate(1, self.data)
-        self.doc = create_document(uri=1, resolver=PassThroughResolver(), loader=ppl, ref_resolution=RefResolutionMode.USE_REFERENCES_OBJECTS)
+        self.doc = create_document(uri=1, loader=ppl, ref_resolution=RefResolutionMode.USE_REFERENCES_OBJECTS)
 
     def test_is_a_reference(self):
         self.assertIsInstance(self.doc['items'][0], DocReference)
